@@ -1,12 +1,16 @@
 """
 CLI entry point.
 """
+import warnings
+
 import click
 
 from .commands.geographic import geo
 from .commands.setup import setup
 from .commands.taxonomic import tax
 
+warnings.filterwarnings("ignore")
+
 
 @click.group()
 def main():
